<?php

namespace Pinpoint\StoreInfo\Block;

/**
 * Class StoreInfo
 * @package Pinpoint\StoreInfo\Block
 */
class StoreInfo extends \Magento\Framework\View\Element\Template
{
    /**
     * @var \Magento\Store\Model\Information
     */
    protected $_storeInfo;

    /**
     * @var \Magento\Store\Model\StoreManagerInterface
     */
    protected $_storeManagerInterface;

    /**
     * @var \Magento\Framework\App\Config\ScopeConfigInterface
     */
    protected $_scopeConfig;

    /**
     * StoreInfo constructor.
     * @param \Magento\Framework\View\Element\Template\Context $context
     * @param \Magento\Store\Model\Information $storeInfo
     * @param \Magento\Store\Model\StoreManagerInterface $storeManagerInterface
     * @param \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig
     * @param array $data
     */
    public function __construct(
        \Magento\Framework\View\Element\Template\Context $context,
        \Magento\Store\Model\Information $storeInfo,
        \Magento\Store\Model\StoreManagerInterface $storeManagerInterface,
        \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig,
        array $data = []
    ) {
        parent::__construct($context, $data);

        $this->_storeInfo = $storeInfo;
        $this->_storeManagerInterface = $storeManagerInterface;
        $this->_scopeConfig = $scopeConfig;
    }

    /**
     * @return string
     */
    public function getPhoneNumber()
    {
        return $this->_storeInfo->getStoreInformationObject($this->_storeManagerInterface->getStore(null))->getPhone();
    }

    /**
     * @return string
     */
    public function getStoreEmail()
    {
        $storeScope = \Magento\Store\Model\ScopeInterface::SCOPE_STORES;
        return $this->_scopeConfig->getValue("trans_email/ident_general/email", $storeScope);
    }

    /**
     * @return string
     */
    public function getStoreAddress()
    {
        $storeScope = \Magento\Store\Model\ScopeInterface::SCOPE_STORES;

        $address = [];
        if ($this->_scopeConfig->getValue("general/store_information/street_line1", $storeScope)):
            $address['streetOne'] = $this->_scopeConfig->getValue("general/store_information/street_line1", $storeScope);
        endif;
        if($this->_scopeConfig->getValue("general/store_information/street_line2", $storeScope)):
            $address['streetTwo'] = $this->_scopeConfig->getValue("general/store_information/street_line2", $storeScope);
        endif;
        if($this->_scopeConfig->getValue("general/store_information/city", $storeScope)):
            $address['city'] = $this->_scopeConfig->getValue("general/store_information/city", $storeScope);
        endif;
        if($this->_scopeConfig->getValue("general/store_information/region_id", $storeScope)):
            $address['region'] = $this->_scopeConfig->getValue("general/store_information/region_id", $storeScope);
        endif;
        if($this->_scopeConfig->getValue("general/store_information/postcode", $storeScope)):
            $address['postcode'] = $this->_scopeConfig->getValue("general/store_information/postcode", $storeScope);
        endif;

        return implode(",<br />", $address);
    }
}
